==> keycloak-model-map-17.0.1-sources.jar: org/keycloak/models/map/authorization/entity/MapPermissionTicketEntityDelegate.java <==
package org.keycloak.models.map.authorization.entity;
public class MapPermissionTicketEntityDelegate implements org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity> delegateProvider;
    public MapPermissionTicketEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.ID, id).setId(id);
    }
    @Override public String getOwner() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.OWNER).getOwner();
    }
    @Override public void setOwner(String owner) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.OWNER, owner).setOwner(owner);
    }
    @Override public String getRequester() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.REQUESTER).getRequester();
    }
    @Override public void setRequester(String requester) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.REQUESTER, requester).setRequester(requester);
    }
    @Override public Long getCreatedTimestamp() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.CREATED_TIMESTAMP).getCreatedTimestamp();
    }
    @Override public void setCreatedTimestamp(Long createdTimestamp) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.CREATED_TIMESTAMP, createdTimestamp).setCreatedTimestamp(createdTimestamp);
    }
    @Override public Long getGrantedTimestamp() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.GRANTED_TIMESTAMP).getGrantedTimestamp();
    }
    @Override public void setGrantedTimestamp(Long grantedTimestamp) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.GRANTED_TIMESTAMP, grantedTimestamp).setGrantedTimestamp(grantedTimestamp);
    }
    @Override public String getResourceId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.RESOURCE_ID).getResourceId();
    }
    @Override public void setResourceId(String resourceId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.RESOURCE_ID, resourceId).setResourceId(resourceId);
    }
    @Override public String getScopeId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.SCOPE_ID).getScopeId();
    }
    @Override public void setScopeId(String scopeId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.SCOPE_ID, scopeId).setScopeId(scopeId);
    }
    @Override public String getResourceServerId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.RESOURCE_SERVER_ID).getResourceServerId();
    }
    @Override public void setResourceServerId(String resourceServerId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.RESOURCE_SERVER_ID, resourceServerId).setResourceServerId(resourceServerId);
    }
    @Override public String getPolicyId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.POLICY_ID).getPolicyId();
    }
    @Override public void setPolicyId(String policyId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.POLICY_ID, policyId).setPolicyId(policyId);
    }
}

==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/authorization/entity/MapPermissionTicketEntityDelegate.java <==
package org.keycloak.models.map.authorization.entity;
public class MapPermissionTicketEntityDelegate implements org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity> delegateProvider;
    public MapPermissionTicketEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.ID, id).setId(id);
    }
    @Override public String getRealmId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.REALM_ID).getRealmId();
    }
    @Override public void setRealmId(String realmId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.REALM_ID, realmId).setRealmId(realmId);
    }
    @Override public String getOwner() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.OWNER).getOwner();
    }
    @Override public void setOwner(String owner) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.OWNER, owner).setOwner(owner);
    }
    @Override public String getRequester() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.REQUESTER).getRequester();
    }
    @Override public void setRequester(String requester) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.REQUESTER, requester).setRequester(requester);
    }
    @Override public Long getCreatedTimestamp() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.CREATED_TIMESTAMP).getCreatedTimestamp();
    }
    @Override public void setCreatedTimestamp(Long createdTimestamp) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.CREATED_TIMESTAMP, createdTimestamp).setCreatedTimestamp(createdTimestamp);
    }
    @Override public Long getGrantedTimestamp() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.GRANTED_TIMESTAMP).getGrantedTimestamp();
    }
    @Override public void setGrantedTimestamp(Long grantedTimestamp) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.GRANTED_TIMESTAMP, grantedTimestamp).setGrantedTimestamp(grantedTimestamp);
    }
    @Override public String getResourceId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.RESOURCE_ID).getResourceId();
    }
    @Override public void setResourceId(String resourceId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.RESOURCE_ID, resourceId).setResourceId(resourceId);
    }
    @Override public String getScopeId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.SCOPE_ID).getScopeId();
    }
    @Override public void setScopeId(String scopeId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.SCOPE_ID, scopeId).setScopeId(scopeId);
    }
    @Override public String getResourceServerId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.RESOURCE_SERVER_ID).getResourceServerId();
    }
    @Override public void setResourceServerId(String resourceServerId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.RESOURCE_SERVER_ID, resourceServerId).setResourceServerId(resourceServerId);
    }
    @Override public String getPolicyId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.POLICY_ID).getPolicyId();
    }
    @Override public void setPolicyId(String policyId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.POLICY_ID, policyId).setPolicyId(policyId);
    }
}
